/*  L A N G    E X T E N S I O N  */

#ifndef EXT_LANG_H
#define EXT_LANG_H

#include <extension.h>


typedef int (*sprint_fn)(char *, int, int);
typedef int (*genfinal_fn)(int);
typedef int (*genhllfile_fn)(FILE *);

struct EXT__LANG {            /* target HighLevelLanguage */
   struct EXTENSION ext;
   int options;
   /* function pointers */
   void *fn_parsehdr;   /* process header for constants, fn protos, etc */
   sprint_fn fn_sprint_proto;
   sprint_fn fn_sprint_func;
   genfinal_fn fn_gen_final;
   genhllfile_fn fn_gen_file;
};
extern struct EXT__LANG *ext_lang;

/* Private Parts ;)  */
	#ifndef INCLUDED_FROM_BASTARD_H

	#endif

#endif
